@@ -1,6 +1,6 @@
 $:.unshift File.dirname(__FILE__)
 
-require 'test/unit'
+require 'minitest/autorun'
 
 require 'array_extensions_test'
 require 'ea_instantiator_test'
@@ -23,4 +23,5 @@ require 'metamodel_from_ecore_test'
 require 'util_test'
 require 'model_fragment_test'
 require 'qualified_name_provider_test'
+require 'ecore_to_ruby_test'
 
